====================
Computer Space Games
====================

.. image:: cover.jpg

`Download the original book <https://drive.google.com/a/semantic.co.uk/file/d/0Bxv0SsvibDMTNlMwTi1PTlVxc2M/view>`__


.. toctree::
   :maxdepth: 1

   starship_takeoff/index
   intergalactic_games/index
   evil_alien/index
   beat_the_bug_eyes/index
   moonlander/index
   monsters_of_galacticon/index
   alien_snipers/index
   asteroid_belt/index
   trip_into_the_future/index
   death_valley/index
   space_mines/index
   space_rescue/index
   touchdown/index
